@@ -1,5 +1,6 @@
 import django
 import django.db
+from django.db import InterfaceError
 
 from .Database import DatabaseStatus
 
@@ -20,11 +21,12 @@ class WaitWaiter(Waiter):
         if database.check_status() == DatabaseStatus.RUNNING.value:
             try:
                 self._executor.run_query(query, database)
-            except django.db.utils.OperationalError:
+            except (django.db.utils.OperationalError,InterfaceError) as e:
                 database.is_up.clear()
                 database.change_status(DatabaseStatus.DOWN.value)
                 self.wait_for_connection(query, database)
         else:
+            database.is_up.clear()
             self.wait_for_connection(query, database)
 
     def wait_for_connection(self, query, database):
